@@ -19,25 +19,33 @@
 #include "kiosk-backgrounds.h"
 #include "kiosk-gobject-utils.h"
 #include "kiosk-input-sources-manager.h"
+#include "kiosk-automount-manager.h"
 #include "kiosk-service.h"
+#include "kiosk-app-system.h"
+#include "kiosk-window-tracker.h"
+#include "kiosk-shell-introspect-service.h"
 
 #include "org.gnome.DisplayManager.Manager.h"
 
 struct _KioskCompositor
 {
-        MetaPlugin                parent;
+        MetaPlugin                   parent;
 
         /* weak references */
-        MetaDisplay              *display;
-        MetaContext              *context;
-        ClutterBackend           *backend;
-        ClutterActor             *stage;
+        MetaDisplay                 *display;
+        MetaContext                 *context;
+        ClutterBackend              *backend;
+        ClutterActor                *stage;
 
         /* strong references */
-        GCancellable             *cancellable;
-        KioskBackgrounds         *backgrounds;
-        KioskInputSourcesManager *input_sources_manager;
-        KioskService             *service;
+        GCancellable                *cancellable;
+        KioskBackgrounds            *backgrounds;
+        KioskInputSourcesManager    *input_sources_manager;
+        KioskAutomountManager       *automount_manager;
+        KioskService                *service;
+        KioskAppSystem              *app_system;
+        KioskWindowTracker          *tracker;
+        KioskShellIntrospectService *introspect_service;
 };
 
 enum
@@ -68,6 +76,7 @@ kiosk_compositor_dispose (GObject *object)
         g_clear_weak_pointer (&self->backend);
 
         g_clear_object (&self->backgrounds);
+        g_clear_object (&self->automount_manager);
 
         G_OBJECT_CLASS (kiosk_compositor_parent_class)->dispose (object);
 }
@@ -235,7 +244,17 @@ kiosk_compositor_start (MetaPlugin *plugin)
         neuter_builtin_keybindings (self);
 
         self->backgrounds = kiosk_backgrounds_new (self);
+        self->automount_manager = kiosk_automount_manager_new (self);
         self->input_sources_manager = kiosk_input_sources_manager_new (self);
+        self->app_system = kiosk_app_system_new (self);
+        self->tracker = kiosk_window_tracker_new (self, self->app_system);
+        self->introspect_service = kiosk_shell_introspect_service_new (self);
+        kiosk_shell_introspect_service_start (self->introspect_service, &error);
+
+        if (error != NULL) {
+                g_debug ("KioskCompositor: Could not start D-Bus service: %s", error->message);
+                g_clear_error (&error);
+        }
 
         kiosk_gobject_utils_queue_immediate_callback (G_OBJECT (self),
                                                       "[kiosk-compositor] register_session",
@@ -425,10 +444,10 @@ kiosk_compositor_kill_switch_workspace (MetaPlugin *plugin)
 }
 
 static void
-kiosk_compositor_show_tile_preview (MetaPlugin    *plugin,
-                                    MetaWindow    *window,
-                                    MtkRectangle  *tile_rect,
-                                    int            tile_monitor)
+kiosk_compositor_show_tile_preview (MetaPlugin   *plugin,
+                                    MetaWindow   *window,
+                                    MtkRectangle *tile_rect,
+                                    int           tile_monitor)
 {
         g_assert (META_PLUGIN_CLASS (kiosk_compositor_parent_class)->show_tile_preview == NULL);
 }
@@ -595,3 +614,19 @@ kiosk_compositor_get_service (KioskCompositor *self)
 
         return KIOSK_SERVICE (self->service);
 }
+
+KioskAppSystem *
+kiosk_compositor_get_app_system (KioskCompositor *self)
+{
+        g_return_val_if_fail (KIOSK_IS_COMPOSITOR (self), NULL);
+
+        return KIOSK_APP_SYSTEM (self->app_system);
+}
+
+KioskWindowTracker *
+kiosk_compositor_get_window_tracker (KioskCompositor *self)
+{
+        g_return_val_if_fail (KIOSK_IS_COMPOSITOR (self), NULL);
+
+        return KIOSK_WINDOW_TRACKER (self->tracker);
+}
